Module problem_mapping

Module problem_mapping 

Mapping from OData errors to Problem (pure data)

This provides a baseline conversion from OData errors to RFC 9457 Problem without HTTP framework dependencies. The HTTP layer in modkit adds instance paths and trace IDs before the Problem is converted to an HTTP response.