pub struct FieldRef<S: Schema, T> { /* private fields */ }Expand description
Type-safe field reference holding schema and Rust type information.
This struct binds a field to both its schema and expected Rust type, enabling compile-time type checking for filter operations.
NOTE: FieldRef equality and hashing are based solely on the underlying
schema field. The generic type parameter T is a phantom type used only for
compile-time validation of operations and is not part of the field identity.
Type Parameters
S- The schema type implementingSchemaT- The Rust type this field represents (e.g.,String,uuid::Uuid)
Implementations
Sourceimpl<S: Schema, T> FieldRef<S, T>
Comparison operations for any field type.
impl<S: Schema, T> FieldRef<S, T>
Comparison operations for any field type.
Sourcepub fn eq<V: IntoODataValue>(self, value: V) -> Expr
pub fn eq<V: IntoODataValue>(self, value: V) -> Expr
Sourcepub fn ne<V: IntoODataValue>(self, value: V) -> Expr
pub fn ne<V: IntoODataValue>(self, value: V) -> Expr
Create a not-equal comparison: field ne value
Sourcepub fn gt<V: IntoODataValue>(self, value: V) -> Expr
pub fn gt<V: IntoODataValue>(self, value: V) -> Expr
Create a greater-than comparison: field gt value
Sourcepub fn ge<V: IntoODataValue>(self, value: V) -> Expr
pub fn ge<V: IntoODataValue>(self, value: V) -> Expr
Create a greater-than-or-equal comparison: field ge value
Sourcepub fn lt<V: IntoODataValue>(self, value: V) -> Expr
pub fn lt<V: IntoODataValue>(self, value: V) -> Expr
Create a less-than comparison: field lt value
Sourcepub fn le<V: IntoODataValue>(self, value: V) -> Expr
pub fn le<V: IntoODataValue>(self, value: V) -> Expr
Create a less-than-or-equal comparison: field le value
Sourcepub fn is_not_null(self) -> Expr
pub fn is_not_null(self) -> Expr